% clear and close all images
clear all
close all
% load phase image
im_phase=imread('phase.tif');
% examine the phase image using imtool to find a threshold to segment out
% cells; remember to add the square brackets to normalize the intensity
imtool(im_phase,[])
% zoom in on the edge of a particular cell, and you will figure out the
% threshold is about 500
threshold=500;
% now, let's create ImThresh using the threshold determined above; remember
% cells on the phase image appear black so that their intensities are
% smaller than the threshold
ImThresh=im_phase<threshold;
imshow(ImThresh,[])
% now let's label ImThresh and get the areas of the identified cells using
% regionprops
ImLabel=bwlabel(ImThresh);
ImRegion=regionprops(ImLabel,'Area');
Areas=[ImRegion.Area];
% now let's create a histogram of the Areas to figure out the area
% selection threshold
figure,hist(Areas)
% add title
title('Histogram of Areas')
% label axes
xlabel('Areas [pixels]')
ylabel('Number')
% examin the histogram, we can see the min. area threhsold is 300 pixels
% apply this area selection to create our mask
Area_Threshold=300;
Approved=find(Areas>Area_Threshold);
% similiar to TPM, we now go through a loop to add in approved cells in the
% mask
ImMask=zeros(size(im_phase));
for i=1:length(Approved)
    ImMask=ImMask+(ImLabel==Approved(i));
end
figure,imshow(ImMask)
% now, let's overlay the mask with the original phase image
ImRescaled=mat2gray(im_phase);
ImOverlay=cat(3,ImMask+ImRescaled,ImRescaled,ImRescaled);
figure,imshow(ImOverlay)

% now, we are ready to compute the mean fluorescence intensity
% load the fluorescence image
im_fluo=imread('fluorescence.tif');
% we want to collect the mean fluorescence intensity corresponding to
% identified cells on the mask; furthermore, we want to subtract the
% background mean fluorescence intensity that are not corresponding to
% identified cells on the mask and also correct cellular autofluorescence
% i.e. mean fluo = <mean fluo of cells> - <background mean fluo> - autofluo 
% where <> indicates average

% There are 2 possibilities for autofluo:
% 1) For the strain that does not fluorescence at all, its autofluo is zero
% 2) For the strain that is fluorescent, its autofluo is the mean fluo from
% the autofluo strain

% let's first examine whehther the fluorescence image we have here contain
% fluorescent cells
figure,imshow(im_fluo,[])
% the cells are indeed fluorescent
% now, let's first define what is autofluo (intensity per pixel); assuming
% this value is 50 fluorescent counts per pixel; you should determin this
% value from your pad with NoFluo strain
AutoFluo=50;
% then, let's calculate the average of mean fluo of identified cells
% remember on ImMask, cells corresponding to 1 and background corresponding
% to 0
MeanFluo=mean(im_fluo(ImMask==1))-mean(im_fluo(ImMask==0))-AutoFluo
% Now, you have the MeanFluo data for this snapshot (about 106 fluorescent
% counts per pixel)!

% At the end, don't forget to add a scale bar on your phase image! You can
% also use ImageJ to do this "Analyze --> Tools --> Scale Bar"





